@@ -108,6 +108,44 @@ mc
 ## -----------------------------------------------------------------------------
 general.indexes(mc = mc)
 
+## -----------------------------------------------------------------------------
+model <- train.lda(Species~., data.train)
+model
+
+## -----------------------------------------------------------------------------
+prediction <- predict(model, data.test , type = "prob")
+prediction
+
+## -----------------------------------------------------------------------------
+prediction <- predict(model, data.test , type = "class")
+prediction
+
+## -----------------------------------------------------------------------------
+mc <- confusion.matrix(data.test, prediction)
+mc
+
+## -----------------------------------------------------------------------------
+general.indexes(mc = mc)
+
+## -----------------------------------------------------------------------------
+model <- train.qda(Species~., data.train)
+model
+
+## -----------------------------------------------------------------------------
+prediction <- predict(model, data.test , type = "prob")
+prediction
+
+## -----------------------------------------------------------------------------
+prediction <- predict(model, data.test , type = "class")
+prediction
+
+## -----------------------------------------------------------------------------
+mc <- confusion.matrix(data.test, prediction)
+mc
+
+## -----------------------------------------------------------------------------
+general.indexes(mc = mc)
+
 ## -----------------------------------------------------------------------------
 model <- train.randomForest(Species~., data.train)
 model
